# Copyright (c) 2016 Dave Love, Liverpool University
# MIT licence, per Fedora policy.

%bcond_with mpich

# fixme: library sover; linking with xdrfile
#        doc build on el7

Name:		plumed
Version:	2.2.1
Release:	2%{?dist}
Summary:	Free energy calculations in molecular systems

License:	LGPLv3+ and BSD
URL:		http://www.plumed.org/
Source0:	https://github.com/plumed/plumed2/archive/v%version.tar.gz#/plumed-%version.tar.gz
BuildRequires:	openmpi-devel libmatheval-devel zlib-devel graphviz
BuildRequires:  openblas-devel %_bindir/xxd doxygen %_bindir/pdflatex
%if 0
%{?el7:BuildRequires:  texlive-latex texlive-texconfig texlive-cm}
%endif
# get link error with this
#BuildRequires:	xdrfile-devel
%if %{with mpich}
BuildRequires:	mpich-devel
%endif

%global desc \
PLUMED is an open source library for free energy calculations in\
molecular systems which works together with some of the most popular\
molecular dynamics engines.  Free energy calculations can be performed\
as a function of many order parameters with a particular focus on\
biological problems, using state of the art methods such as\
metadynamics, umbrella sampling and Jarzynski-equation based steered\
MD.  The software, written in C++, can be easily interfaced with both\
Fortran and C/C++ codes.\
\
G.A. Tribello, M. Bonomi, D. Branduardi, C. Camilloni, G. Bussi,\
PLUMED2: New feathers for an old bird, Comp. Phys. Comm. 185, 604 (2014)

%description
%desc

This is a serial version.

%package devel
Summary: Development files for %name

%description devel
Development files for %name

%package doc
Summary: Documentation for %name
BuildArch: noarch

%description doc
Documentation for %name

%package openmpi
Summary: Free energy calculations in molecular systems - openmpi
Requires: openmpi%{_isa}

%description openmpi
%desc

This is an openmpi version.

%package openmpi-devel
Summary: Development files for %name-openmpi
Requires: openmpi%{_isa}
Requires: %name-openmpi%{?_isa} = %version-%release

%description openmpi-devel
Development files for %name-openmpi

%if %{with mpich}
%package mpich
Summary: Free energy calculations in molecular systems - mpich
Requires: mpich%{_isa}

%description mpich
%desc

This is an mpich version.

%package mpich-devel
Summary: Development files for %name-mpich
Requires: mpich%{_isa}
Requires: %name-mpich%{?_isa} = %version-%release

%description mpich-devel
Development files for %name-mpich
%endif


%prep
%setup -q -c
mv plumed* serial
cp -a serial openmpi
%if %{with mpich}
cp -a serial mpich
%endif


%build

export LIBS=-lopenblas
export LDFLAGS=-Wl,--as-needed
pushd serial
%configure --disable-mpi
make %{?_smp_mflags}
%{!?el7:make doc}
popd

pushd openmpi
%_openmpi_load
%configure --libdir=$MPI_LIB --includedir=$MPI_INCLUDE --bindir=$MPI_BIN
make %{?_smp_mflags}
%_openmpi_unload
popd

%if %{with mpich}
pushd mpich
%_mpich_load
%configure --libdir=$MPI_LIB --includedir=$MPI_INCLUDE --bindir=$MPI_BIN
make %{?_smp_mflags}
%_mpich_unload
popd
%endif


%check
pushd serial
make -C regtest
popd


%install
make -C serial install DESTDIR=$RPM_BUILD_ROOT
%_openmpi_load
make -C openmpi install DESTDIR=$RPM_BUILD_ROOT
%_openmpi_unload
%if %{with mpich}
%_mpich_load
make -C mpich install DESTDIR=$RPM_BUILD_ROOT
%_mpich_unload
%endif


%files
%doc serial/COPYING.LESSER serial/CHANGES serial/PEOPLE
%_bindir/plumed
%_libdir/*.so

%files devel
%_bindir/plumed-patch
%_includedir/plumed
%_libdir/plumed
%_libdir/*.so

%if ! 0%{?el7}
%files doc
%doc serial/COPYING.LESSER serial/CHANGES serial/PEOPLE
%_docdir/plumed
%endif

%files openmpi
%doc openmpi/COPYING.LESSER openmpi/CHANGES openmpi/PEOPLE
%_libdir/openmpi/bin/plumed
%_libdir/openmpi/lib/plumed
%_libdir/openmpi/lib/*.so

%files openmpi-devel
%_includedir/openmpi-%_arch/plumed
%_libdir/openmpi/bin/plumed-patch

%if %{with mpich}
%files mpich
%doc mpich/COPYING.LESSER mpich/CHANGES mpich/PEOPLE
%_libdir/mpich/bin/plumed
%_libdir/mpich/lib/plumed
%_libdir/mpich/lib/*.so

%files mpich-devel
%_includedir/mpich-%_arch/plumed
%_libdir/mpich/bin/plumed-patch
%endif


%changelog
* Fri Oct  7 2016 Dave Love <loveshack@fedoraproject.org> - 2.2.1-2
- Fix doc build on el7

* Sat Apr  2 2016 Dave Love <loveshack@fedoraproject.org> - 2.2.1-1
- New version

* Fri Feb 13 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1.1-1
- Initial packaging
